%global version_major 1
%global version_minor 12
%global version_patch 0

Name:		liblsl
Version:	%{version_major}.%{version_minor}.%{version_patch}
Release:	4%{?dist}
Summary:	Lab streaming layer API

License:	MIT
URL:		https://github.com/sccn/labstreaminglayer

# Source archived from git repo, excluding external libraries like boost:
# git clone https://github.com/sccn/labstreaminglayer.git
# cd labstreaminglayer/LSL/liblsl
# git archive --prefix=%%{name}-%%{version}/ v%%{version} `ls | grep -v '^external$'` | xz > %%{SOURCE0}
Source0:	%{name}-%{version}.tar.xz
Patch0:		liblsl_allow_redefine_version.patch
Patch1:		liblsl_fix_boost_include.patch
Patch2:		liblsl-1.12.0-so_version.patch
Patch3:		liblsl-1.12.0-install.patch
Patch4:		liblsl-1.12.0-use_system_pugixml.patch
Patch5:		liblsl-1.12.0-drop_legacy_abi.patch
# Patch to fix a typo in the endian conversion code from boost
Patch6:		liblsl-boost-bigendian.patch
# Fix for boost-1.66 and newer
Patch7:		liblsl-1.12.0-new_boost.patch
Patch8:		liblsl-1.12.0-include.patch

BuildRequires:  gcc-c++
BuildRequires:	boost-devel
BuildRequires:	cmake
BuildRequires:	dos2unix
BuildRequires:	pugixml-devel

Provides:	bundled(boost-endian)
Provides:	bundled(portable-archive)

%description
The lab streaming layer is a simple all-in-one approach to streaming experiment
data between applications in a lab, e.g. instrument time series, event markers,
audio, and so on.


%package devel
Summary:	Lab streaming layer API development files
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
Development files for liblsl.


%prep
%autosetup -p1
dos2unix CHANGELOG README examples/*/*/*.{c,cpp}
find examples -type f \( -name '*.c' -o -name '*.cpp' \) -exec \
    sed -i '/^#include/s|\.\./\.\./\.\./include/||' {} \;
find examples -type f -name '*.vcproj' -delete
find examples -type f -name '*.vcxproj' -delete
find examples -type d -name '*.xcodeproj' -exec rm -rf {} +


%build
mkdir build
pushd build
%cmake \
    -DUSE_SYSTEM_BOOST=ON \
    -Dliblsl_VERSION_MAJOR=%{version_major} \
    -Dliblsl_VERSION_MINOR=%{version_minor} \
    -Dliblsl_VERSION_PATCH=%{version_patch} \
    ..
%make_build
popd


%install
pushd build
%make_install
popd


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%license LICENSE src/portable_archive/license.txt
%doc AUTHORS BUGS CHANGELOG NEWS README THANKS
%{_libdir}/*.so.*

%files devel
%doc examples
%{_includedir}/*.h
%{_includedir}/%{name}
%{_libdir}/*.so


%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Jun 14 2018 Dmitry Mikhirev <mikhirev@gmail.com> - 1.12.0-3
- Fix build with boost 1.66+ (#1556596)

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Nov 26 2017 Dmitry Mikhirev <mikhirev@gmail.com> - 1.12.0-1
- New upstream release (#1504351)
- Convert line endings in examples to unix format

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.11.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.11.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Jul 19 2017 Jonathan Wakely <jwakely@redhat.com> - 1.11.0-8
- Rebuilt for s390x binutils bug

* Tue Jul 18 2017 Jonathan Wakely <jwakely@redhat.com> - 1.11.0-7
- Rebuilt for Boost 1.64

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.11.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Tue Feb 07 2017 Kalev Lember <klember@redhat.com> - 1.11.0-5
- Rebuilt for Boost 1.63

* Wed Dec 28 2016 Rich Mattes <richmattes@gmail.com> - 1.11.0-4
- Rebuild for added alternate architectures
- Fix bigendian issue with included endian header

* Tue May 17 2016 Jonathan Wakely <jwakely@redhat.com> - 1.11.0-3
- Rebuilt for linker errors in boost (#1331983)

* Sun Feb 14 2016 Dmitry Mikhirev <mikhirev@gmail.com> 1.11.0-2
- Dropped legacy ABI support to fix build on armv7hl

* Thu Dec 31 2015 Dmitry Mikhirev <mikhirev@gmail.com> 1.11.0-1
- Initial package
